@@ -35,6 +35,8 @@ from subprocess import CompletedProcess
 from typing import Any, Mapping, Sequence, cast
 from urllib.parse import urlparse
 
+import rtoml
+
 
 @dataclass
 class RunResult:
@@ -118,41 +120,6 @@ class ProjectMetadata:
 
 _PYPROJECT_DATA_CACHE: dict[Path, dict[str, object]] = {}
 _METADATA_CACHE: dict[Path, ProjectMetadata] = {}
-_toml_module: Any = None
-
-
-def _get_toml_module() -> Any:
-    """Return tomllib (Python 3.11+) or tomli backport (Python 3.9-3.10).
-
-    Purpose
-    -------
-    Ensure TOML parsing works across Python 3.9+ by using the standard
-    library tomllib on 3.11+ and falling back to the tomli package
-    on earlier versions.
-
-    Returns
-    -------
-    module
-        Either tomllib or tomli with identical interfaces.
-
-    Raises
-    ------
-    ModuleNotFoundError
-        If neither tomllib nor tomli can be imported.
-    """
-    global _toml_module
-    if _toml_module is not None:
-        return _toml_module
-
-    # Use tomllib (Python 3.11+) or tomli backport (Python 3.9-3.10)
-    # Both have the same interface, so we can treat them interchangeably
-    try:
-        import tomllib as module  # type: ignore[import-not-found]
-    except ModuleNotFoundError:
-        import tomli as module  # type: ignore[import-not-found,no-redef]
-
-    _toml_module = module
-    return module
 
 
 def run(
@@ -250,10 +217,9 @@ def _load_pyproject(pyproject: Path) -> dict[str, object]:
     if cached is not None:
         return cached
     raw_text = path.read_text(encoding="utf-8")
-    toml_module = _get_toml_module()
     try:
-        parsed_obj = toml_module.loads(raw_text)
-    except toml_module.TOMLDecodeError as exc:  # pragma: no cover - invalid pyproject fails fast
+        parsed_obj = rtoml.loads(raw_text)
+    except rtoml.TomlParsingError as exc:  # pragma: no cover - invalid pyproject fails fast
         msg = f"Unable to parse {path}: {exc}"
         raise ValueError(msg) from exc
     data = {str(key): value for key, value in parsed_obj.items()}
